# lotus_client
Lotus is an open-core pricing and billing engine. We enable API companies to automate and optimize their custom usage-based pricing for any metric.

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 0.9.3
- Package version: 1.0.1
- Build package: io.swagger.codegen.v3.generators.python.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import lotus_client 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import lotus_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import lotus_client
from lotus_client.rest import ApiException
from pprint import pprint

# Configure API key authorization: OrganizationApiKeyAuth
configuration = lotus_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'
# Configure API key authorization: knoxTokenAuth
configuration = lotus_client.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = lotus_client.ApiApi(lotus_client.ApiClient(configuration))
body = lotus_client.CustomerBalanceAdjustmentCreateRequest() # CustomerBalanceAdjustmentCreateRequest | 

try:
    api_response = api_instance.api_credits_create(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ApiApi->api_credits_create: %s\n" % e)

# Configure API key authorization: OrganizationApiKeyAuth
configuration = lotus_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'
# Configure API key authorization: knoxTokenAuth
configuration = lotus_client.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = lotus_client.ApiApi(lotus_client.ApiClient(configuration))
customer_id = 'customer_id_example' # str | The id provided when creating the customer, we suggest matching with your internal customer id in your backend
currency_code = 'currency_code_example' # str | Filter to adjustments in a specific currency (optional)
effective_after = '2013-10-20T19:20:30+01:00' # datetime | Filter to adjustments that are effective after this date (optional)
effective_before = '2013-10-20T19:20:30+01:00' # datetime | Filter to adjustments that are effective before this date (optional)
expires_after = '2013-10-20T19:20:30+01:00' # datetime | Filter to adjustments that expire after this date (optional)
expires_before = '2013-10-20T19:20:30+01:00' # datetime | Filter to adjustments that expire before this date (optional)
issued_after = '2013-10-20T19:20:30+01:00' # datetime | Filter to adjustments that were issued after this date (optional)
issued_before = '2013-10-20T19:20:30+01:00' # datetime | Filter to adjustments that were issued before this date (optional)
status = ['[\"inactive\",\"active\"]'] # list[str] | Filter to a specific set of adjustment statuses. Defaults to both active and inactive. (optional) (default to ["inactive","active"])

try:
    api_response = api_instance.api_credits_list(customer_id, currency_code=currency_code, effective_after=effective_after, effective_before=effective_before, expires_after=expires_after, expires_before=expires_before, issued_after=issued_after, issued_before=issued_before, status=status)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ApiApi->api_credits_list: %s\n" % e)

# Configure API key authorization: OrganizationApiKeyAuth
configuration = lotus_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'
# Configure API key authorization: knoxTokenAuth
configuration = lotus_client.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = lotus_client.ApiApi(lotus_client.ApiClient(configuration))
credit_id = 'credit_id_example' # str | The ID of the credit to retrieve or update.

try:
    api_response = api_instance.api_credits_retrieve(credit_id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ApiApi->api_credits_retrieve: %s\n" % e)

# Configure API key authorization: OrganizationApiKeyAuth
configuration = lotus_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'
# Configure API key authorization: knoxTokenAuth
configuration = lotus_client.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = lotus_client.ApiApi(lotus_client.ApiClient(configuration))
credit_id = 'credit_id_example' # str | The ID of the credit to retrieve or update.
body = lotus_client.CustomerBalanceAdjustmentUpdateRequest() # CustomerBalanceAdjustmentUpdateRequest |  (optional)

try:
    api_response = api_instance.api_credits_update_create(credit_id, body=body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ApiApi->api_credits_update_create: %s\n" % e)

# Configure API key authorization: OrganizationApiKeyAuth
configuration = lotus_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'
# Configure API key authorization: knoxTokenAuth
configuration = lotus_client.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = lotus_client.ApiApi(lotus_client.ApiClient(configuration))
credit_id = 'credit_id_example' # str | The ID of the credit to retrieve or update.

try:
    api_response = api_instance.api_credits_void_create(credit_id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ApiApi->api_credits_void_create: %s\n" % e)

# Configure API key authorization: OrganizationApiKeyAuth
configuration = lotus_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'

# create an instance of the API class
api_instance = lotus_client.ApiApi(lotus_client.ApiClient(configuration))
customer_id = 'customer_id_example' # str | The customer_id of the customer you want to check access.
feature_name = 'feature_name_example' # str | Name of the feature to check access for.
subscription_filters = [lotus_client.SubscriptionFilterRequest()] # list[SubscriptionFilterRequest] | The subscription filters that are applied to this plan's relationship with the customer. If your billing model does not have the ability multiple plans or subscriptions per customer, this is likely not relevant for you. This must be passed in as a stringified JSON object. (optional)

try:
    api_response = api_instance.api_customer_feature_access_list(customer_id, feature_name, subscription_filters=subscription_filters)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ApiApi->api_customer_feature_access_list: %s\n" % e)

# Configure API key authorization: OrganizationApiKeyAuth
configuration = lotus_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'

# create an instance of the API class
api_instance = lotus_client.ApiApi(lotus_client.ApiClient(configuration))
customer_id = 'customer_id_example' # str | The customer_id of the customer you want to check access.
event_name = 'event_name_example' # str | The name of the event you are checking access for. (optional)
metric_id = '38400000-8cf0-11bd-b23e-10b96e4ef00d' # str | The metric_id of the metric you are checking access for. Please note that you must porovide exactly one of event_name and metric_id are mutually; a validation error will be thrown if both or none are provided. (optional)
subscription_filters = [lotus_client.SubscriptionFilterRequest()] # list[SubscriptionFilterRequest] | The subscription filters that are applied to this plan's relationship with the customer. If your billing model does not have the ability multiple plans or subscriptions per customer, this is likely not relevant for you. This must be passed in as a stringified JSON object. (optional)

try:
    api_response = api_instance.api_customer_metric_access_list(customer_id, event_name=event_name, metric_id=metric_id, subscription_filters=subscription_filters)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ApiApi->api_customer_metric_access_list: %s\n" % e)

# Configure API key authorization: OrganizationApiKeyAuth
configuration = lotus_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'
# Configure API key authorization: knoxTokenAuth
configuration = lotus_client.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = lotus_client.ApiApi(lotus_client.ApiClient(configuration))
customer_id = 'customer_id_example' # str | 
end_date = '2013-10-20' # date | 
start_date = '2013-10-20' # date | 

try:
    api_response = api_instance.api_customers_cost_analysis_retrieve(customer_id, end_date, start_date)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ApiApi->api_customers_cost_analysis_retrieve: %s\n" % e)

# Configure API key authorization: OrganizationApiKeyAuth
configuration = lotus_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'
# Configure API key authorization: knoxTokenAuth
configuration = lotus_client.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = lotus_client.ApiApi(lotus_client.ApiClient(configuration))
body = lotus_client.CustomerCreateRequest() # CustomerCreateRequest | 

try:
    api_response = api_instance.api_customers_create(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ApiApi->api_customers_create: %s\n" % e)

# Configure API key authorization: OrganizationApiKeyAuth
configuration = lotus_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'
# Configure API key authorization: knoxTokenAuth
configuration = lotus_client.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = lotus_client.ApiApi(lotus_client.ApiClient(configuration))
customer_id = 'customer_id_example' # str | 

try:
    api_response = api_instance.api_customers_delete_create(customer_id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ApiApi->api_customers_delete_create: %s\n" % e)

# Configure API key authorization: OrganizationApiKeyAuth
configuration = lotus_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'
# Configure API key authorization: knoxTokenAuth
configuration = lotus_client.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = lotus_client.ApiApi(lotus_client.ApiClient(configuration))
customer_id = 'customer_id_example' # str | 
include_next_period = true # bool |  (optional) (default to true)

try:
    api_instance.api_customers_draft_invoice_retrieve(customer_id, include_next_period=include_next_period)
except ApiException as e:
    print("Exception when calling ApiApi->api_customers_draft_invoice_retrieve: %s\n" % e)

# Configure API key authorization: OrganizationApiKeyAuth
configuration = lotus_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'
# Configure API key authorization: knoxTokenAuth
configuration = lotus_client.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = lotus_client.ApiApi(lotus_client.ApiClient(configuration))

try:
    api_response = api_instance.api_customers_list()
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ApiApi->api_customers_list: %s\n" % e)

# Configure API key authorization: OrganizationApiKeyAuth
configuration = lotus_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'
# Configure API key authorization: knoxTokenAuth
configuration = lotus_client.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = lotus_client.ApiApi(lotus_client.ApiClient(configuration))
customer_id = 'customer_id_example' # str | 

try:
    api_response = api_instance.api_customers_retrieve(customer_id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ApiApi->api_customers_retrieve: %s\n" % e)

# Configure API key authorization: OrganizationApiKeyAuth
configuration = lotus_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'

# create an instance of the API class
api_instance = lotus_client.ApiApi(lotus_client.ApiClient(configuration))
customer_id = 'customer_id_example' # str | The customer_id of the customer you want to check access.
feature_id = '38400000-8cf0-11bd-b23e-10b96e4ef00d' # str | The feature_id of the feature you want to check access for.
subscription_filters = [lotus_client.SubscriptionFilterRequest()] # list[SubscriptionFilterRequest] | The subscription filters that are applied to this plan's relationship with the customer. If your billing model does not have the ability multiple plans or subscriptions per customer, this is likely not relevant for you.  (optional)

try:
    api_response = api_instance.api_feature_access_retrieve(customer_id, feature_id, subscription_filters=subscription_filters)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ApiApi->api_feature_access_retrieve: %s\n" % e)

# Configure API key authorization: OrganizationApiKeyAuth
configuration = lotus_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'

# create an instance of the API class
api_instance = lotus_client.ApiApi(lotus_client.ApiClient(configuration))

try:
    api_instance.api_healthcheck_retrieve()
except ApiException as e:
    print("Exception when calling ApiApi->api_healthcheck_retrieve: %s\n" % e)

# Configure API key authorization: OrganizationApiKeyAuth
configuration = lotus_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'
# Configure API key authorization: knoxTokenAuth
configuration = lotus_client.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = lotus_client.ApiApi(lotus_client.ApiClient(configuration))
customer_id = 'customer_id_example' # str | A filter for invoices for a specific customer (optional)
payment_status = ['[\"paid\"]'] # list[str] | A filter for invoices with a specific payment status (optional) (default to ["paid"])

try:
    api_response = api_instance.api_invoices_list(customer_id=customer_id, payment_status=payment_status)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ApiApi->api_invoices_list: %s\n" % e)

# Configure API key authorization: OrganizationApiKeyAuth
configuration = lotus_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'
# Configure API key authorization: knoxTokenAuth
configuration = lotus_client.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = lotus_client.ApiApi(lotus_client.ApiClient(configuration))
invoice_id = '38400000-8cf0-11bd-b23e-10b96e4ef00d' # str | 
body = lotus_client.PatchedInvoiceUpdateRequest() # PatchedInvoiceUpdateRequest |  (optional)

try:
    api_response = api_instance.api_invoices_partial_update(invoice_id, body=body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ApiApi->api_invoices_partial_update: %s\n" % e)

# Configure API key authorization: OrganizationApiKeyAuth
configuration = lotus_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'
# Configure API key authorization: knoxTokenAuth
configuration = lotus_client.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = lotus_client.ApiApi(lotus_client.ApiClient(configuration))
invoice_id = 'invoice_id_example' # str | Either an invoice ID (in the format `invoice_<uuid>`) or an invoice number (in the format `YYMMDD-000001`)

try:
    api_response = api_instance.api_invoices_pdf_url_retrieve(invoice_id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ApiApi->api_invoices_pdf_url_retrieve: %s\n" % e)

# Configure API key authorization: OrganizationApiKeyAuth
configuration = lotus_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'
# Configure API key authorization: knoxTokenAuth
configuration = lotus_client.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = lotus_client.ApiApi(lotus_client.ApiClient(configuration))
invoice_id = '38400000-8cf0-11bd-b23e-10b96e4ef00d' # str | 

try:
    api_response = api_instance.api_invoices_retrieve(invoice_id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ApiApi->api_invoices_retrieve: %s\n" % e)

# Configure API key authorization: OrganizationApiKeyAuth
configuration = lotus_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'

# create an instance of the API class
api_instance = lotus_client.ApiApi(lotus_client.ApiClient(configuration))
customer_id = 'customer_id_example' # str | The customer_id of the customer you want to check access.
metric_id = '38400000-8cf0-11bd-b23e-10b96e4ef00d' # str | The metric_id of the metric you want to check access for.
subscription_filters = [lotus_client.SubscriptionFilterRequest()] # list[SubscriptionFilterRequest] | Used if you want to restrict the access check to only plans that fulfill certain subscription filter criteria. If your billing model does not have the ability multiple plans or subscriptions per customer, this is likely not relevant for you.  (optional)

try:
    api_response = api_instance.api_metric_access_retrieve(customer_id, metric_id, subscription_filters=subscription_filters)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ApiApi->api_metric_access_retrieve: %s\n" % e)

# Configure API key authorization: OrganizationApiKeyAuth
configuration = lotus_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'
# Configure API key authorization: knoxTokenAuth
configuration = lotus_client.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = lotus_client.ApiApi(lotus_client.ApiClient(configuration))

try:
    api_response = api_instance.api_ping_retrieve()
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ApiApi->api_ping_retrieve: %s\n" % e)

# Configure API key authorization: OrganizationApiKeyAuth
configuration = lotus_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'
# Configure API key authorization: knoxTokenAuth
configuration = lotus_client.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = lotus_client.ApiApi(lotus_client.ApiClient(configuration))
body = lotus_client.PlanRequest() # PlanRequest | 

try:
    api_response = api_instance.api_plans_create(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ApiApi->api_plans_create: %s\n" % e)

# Configure API key authorization: OrganizationApiKeyAuth
configuration = lotus_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'
# Configure API key authorization: knoxTokenAuth
configuration = lotus_client.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = lotus_client.ApiApi(lotus_client.ApiClient(configuration))
body = lotus_client.CustomerPlanPriceRequest() # CustomerPlanPriceRequest | 
plan_id = 'plan_id_example' # str | The ID of the plan to get price

try:
    api_response = api_instance.api_plans_get_plan_price_for_customer_create(body, plan_id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ApiApi->api_plans_get_plan_price_for_customer_create: %s\n" % e)

# Configure API key authorization: OrganizationApiKeyAuth
configuration = lotus_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'
# Configure API key authorization: knoxTokenAuth
configuration = lotus_client.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = lotus_client.ApiApi(lotus_client.ApiClient(configuration))
duration = 'duration_example' # str | Filter to plans that have this duration.  * `monthly` - Monthly * `quarterly` - Quarterly * `yearly` - Yearly (optional)
exclude_tags = ['exclude_tags_example'] # list[str] | Filter to plans that do not have any of the tags in this list. (optional)
include_tags = ['include_tags_example'] # list[str] | Filter to plans that have any of the tags in this list. (optional)
include_tags_all = ['include_tags_all_example'] # list[str] | Filter to plans that have all of the tags in this list. (optional)
version_currency_code = 'version_currency_code_example' # str | Filter to versions that have the currency specified by this currency code. (optional)
version_custom_type = 'all' # str | Filter to versions that have this custom type. If you choose custom_only, you will only see versions that have target customers. If you choose public_only, you will only see versions that do not have target customers.  * `custom_only` - Custom Only * `public_only` - Public Only * `all` - All (optional) (default to all)
version_status = ['[\"not_started\",\"active\",\"ended\"]'] # list[str] | Filter to versions that have this status. Ended means it has an active_to date in the past. Not started means it has an active_from date in the future or null. (optional) (default to ["not_started","active","ended"])

try:
    api_response = api_instance.api_plans_list(duration=duration, exclude_tags=exclude_tags, include_tags=include_tags, include_tags_all=include_tags_all, version_currency_code=version_currency_code, version_custom_type=version_custom_type, version_status=version_status)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ApiApi->api_plans_list: %s\n" % e)

# Configure API key authorization: OrganizationApiKeyAuth
configuration = lotus_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'
# Configure API key authorization: knoxTokenAuth
configuration = lotus_client.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = lotus_client.ApiApi(lotus_client.ApiClient(configuration))
plan_id = '38400000-8cf0-11bd-b23e-10b96e4ef00d' # str | 
version_currency_code = 'version_currency_code_example' # str | Filter to versions that have the currency specified by this currency code. (optional)
version_custom_type = 'all' # str | Filter to versions that have this custom type. If you choose custom_only, you will only see versions that have target customers. If you choose public_only, you will only see versions that do not have target customers.  * `custom_only` - Custom Only * `public_only` - Public Only * `all` - All (optional) (default to all)
version_status = ['[\"not_started\",\"active\",\"ended\"]'] # list[str] | Filter to versions that have this status. Ended means it has an active_to date in the past. Not started means it has an active_from date in the future or null. (optional) (default to ["not_started","active","ended"])

try:
    api_response = api_instance.api_plans_retrieve(plan_id, version_currency_code=version_currency_code, version_custom_type=version_custom_type, version_status=version_status)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ApiApi->api_plans_retrieve: %s\n" % e)

# Configure API key authorization: OrganizationApiKeyAuth
configuration = lotus_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'
# Configure API key authorization: knoxTokenAuth
configuration = lotus_client.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = lotus_client.ApiApi(lotus_client.ApiClient(configuration))
body = lotus_client.SubscriptionRecordCreateSerializerOldRequest() # SubscriptionRecordCreateSerializerOldRequest | 

try:
    api_response = api_instance.api_subscriptions_add_create(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ApiApi->api_subscriptions_add_create: %s\n" % e)

# Configure API key authorization: OrganizationApiKeyAuth
configuration = lotus_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'
# Configure API key authorization: knoxTokenAuth
configuration = lotus_client.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = lotus_client.ApiApi(lotus_client.ApiClient(configuration))
subscription_id = 'subscription_id_example' # str | The ID of the subscription to add an addon to.
body = lotus_client.AddOnSubscriptionRecordCreateRequest() # AddOnSubscriptionRecordCreateRequest |  (optional)

try:
    api_response = api_instance.api_subscriptions_addons_attach_create(subscription_id, body=body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ApiApi->api_subscriptions_addons_attach_create: %s\n" % e)

# Configure API key authorization: OrganizationApiKeyAuth
configuration = lotus_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'
# Configure API key authorization: knoxTokenAuth
configuration = lotus_client.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = lotus_client.ApiApi(lotus_client.ApiClient(configuration))
addon_id = 'addon_id_example' # str | The ID of the addon within the subscription update.
subscription_id = 'subscription_id_example' # str | The ID of the subscription to update.
body = lotus_client.SubscriptionRecordCancelRequest() # SubscriptionRecordCancelRequest |  (optional)

try:
    api_response = api_instance.api_subscriptions_addons_cancel_create(addon_id, subscription_id, body=body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ApiApi->api_subscriptions_addons_cancel_create: %s\n" % e)

# Configure API key authorization: OrganizationApiKeyAuth
configuration = lotus_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'
# Configure API key authorization: knoxTokenAuth
configuration = lotus_client.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = lotus_client.ApiApi(lotus_client.ApiClient(configuration))
customer_id = 'customer_id_example' # str | Filter to a specific customer.
body = lotus_client.SubscriptionRecordCancelRequest() # SubscriptionRecordCancelRequest |  (optional)
plan_id = '38400000-8cf0-11bd-b23e-10b96e4ef00d' # str | Filter to a specific plan. If not specified, all plans will be included in the cancellation request. (optional)
subscription_filters = [lotus_client.SubscriptionFilterRequest()] # list[SubscriptionFilterRequest] | Filter to a specific set of subscription filters. If your billing model only allows for one subscription per customer, you very likely do not need this field. Must be formatted as a JSON-encoded + stringified list of dictionaries, where each dictionary has a key of 'property_name' and a key of 'value'. (optional)

try:
    api_response = api_instance.api_subscriptions_cancel_create(customer_id, body=body, plan_id=plan_id, subscription_filters=subscription_filters)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ApiApi->api_subscriptions_cancel_create: %s\n" % e)

# Configure API key authorization: OrganizationApiKeyAuth
configuration = lotus_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'
# Configure API key authorization: knoxTokenAuth
configuration = lotus_client.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = lotus_client.ApiApi(lotus_client.ApiClient(configuration))
subscription_id = 'subscription_id_example' # str | The ID of the subscription to cancel.
body = lotus_client.SubscriptionRecordCancelRequest() # SubscriptionRecordCancelRequest |  (optional)

try:
    api_response = api_instance.api_subscriptions_cancel_create2(subscription_id, body=body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ApiApi->api_subscriptions_cancel_create2: %s\n" % e)

# Configure API key authorization: OrganizationApiKeyAuth
configuration = lotus_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'
# Configure API key authorization: knoxTokenAuth
configuration = lotus_client.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = lotus_client.ApiApi(lotus_client.ApiClient(configuration))
body = lotus_client.ChangePrepaidUnitsRequest() # ChangePrepaidUnitsRequest | 
metric_id = 'metric_id_example' # str | The ID of the metric to alter the prepaid usage for.
subscription_id = 'subscription_id_example' # str | The ID of the subscription which will have its plans switched.

try:
    api_response = api_instance.api_subscriptions_components_change_prepaid_units_create(body, metric_id, subscription_id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ApiApi->api_subscriptions_components_change_prepaid_units_create: %s\n" % e)

# Configure API key authorization: OrganizationApiKeyAuth
configuration = lotus_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'
# Configure API key authorization: knoxTokenAuth
configuration = lotus_client.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = lotus_client.ApiApi(lotus_client.ApiClient(configuration))
body = lotus_client.SubscriptionRecordCreateRequest() # SubscriptionRecordCreateRequest | 

try:
    api_response = api_instance.api_subscriptions_create(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ApiApi->api_subscriptions_create: %s\n" % e)

# Configure API key authorization: OrganizationApiKeyAuth
configuration = lotus_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'
# Configure API key authorization: knoxTokenAuth
configuration = lotus_client.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = lotus_client.ApiApi(lotus_client.ApiClient(configuration))
body = lotus_client.UnitMetricExtensionRequest() # UnitMetricExtensionRequest | 
subscription_id = 'subscription_id_example' # str | 

try:
    api_response = api_instance.api_subscriptions_get_price_for_extension_create(body, subscription_id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ApiApi->api_subscriptions_get_price_for_extension_create: %s\n" % e)

# Configure API key authorization: OrganizationApiKeyAuth
configuration = lotus_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'
# Configure API key authorization: knoxTokenAuth
configuration = lotus_client.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = lotus_client.ApiApi(lotus_client.ApiClient(configuration))
subscription_id = 'subscription_id_example' # str | 

try:
    api_response = api_instance.api_subscriptions_get_price_for_renewal_retrieve(subscription_id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ApiApi->api_subscriptions_get_price_for_renewal_retrieve: %s\n" % e)

# Configure API key authorization: OrganizationApiKeyAuth
configuration = lotus_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'
# Configure API key authorization: knoxTokenAuth
configuration = lotus_client.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = lotus_client.ApiApi(lotus_client.ApiClient(configuration))
customer_id = 'customer_id_example' # str | Filter to a specific customer.
plan_id = '38400000-8cf0-11bd-b23e-10b96e4ef00d' # str | Filter to a specific plan. (optional)
range_end = '2013-10-20T19:20:30+01:00' # datetime | If specified, will only return subscriptions with a start date before this date. (optional)
range_start = '2013-10-20T19:20:30+01:00' # datetime | If specified, will only return subscriptions with an end date after this date. (optional)
status = ['[\"active\"]'] # list[str] | Filter to a specific set of subscription statuses. Defaults to active. (optional) (default to ["active"])
subscription_filters = [lotus_client.SubscriptionFilterRequest()] # list[SubscriptionFilterRequest] | Filter to a specific set of subscription filters. If your billing model only allows for one subscription per customer, you very likely do not need this field. Must be formatted as a JSON-encoded + stringified list of dictionaries, where each dictionary has a key of 'property_name' and a key of 'value'. (optional)

try:
    api_response = api_instance.api_subscriptions_list(customer_id, plan_id=plan_id, range_end=range_end, range_start=range_start, status=status, subscription_filters=subscription_filters)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ApiApi->api_subscriptions_list: %s\n" % e)

# Configure API key authorization: OrganizationApiKeyAuth
configuration = lotus_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'
# Configure API key authorization: knoxTokenAuth
configuration = lotus_client.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = lotus_client.ApiApi(lotus_client.ApiClient(configuration))
subscription_id = 'subscription_id_example' # str | 

try:
    api_response = api_instance.api_subscriptions_retrieve(subscription_id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ApiApi->api_subscriptions_retrieve: %s\n" % e)

# Configure API key authorization: OrganizationApiKeyAuth
configuration = lotus_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'
# Configure API key authorization: knoxTokenAuth
configuration = lotus_client.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = lotus_client.ApiApi(lotus_client.ApiClient(configuration))
subscription_id = 'subscription_id_example' # str | The ID of the subscription which will have its plans switched.
body = lotus_client.SubscriptionRecordSwitchPlanRequest() # SubscriptionRecordSwitchPlanRequest |  (optional)

try:
    api_response = api_instance.api_subscriptions_switch_plan_create(subscription_id, body=body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ApiApi->api_subscriptions_switch_plan_create: %s\n" % e)

# Configure API key authorization: OrganizationApiKeyAuth
configuration = lotus_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'
# Configure API key authorization: knoxTokenAuth
configuration = lotus_client.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = lotus_client.ApiApi(lotus_client.ApiClient(configuration))
customer_id = 'customer_id_example' # str | Filter to a specific customer.
plan_id = '38400000-8cf0-11bd-b23e-10b96e4ef00d' # str | Filter to a specific plan.
body = lotus_client.SubscriptionRecordUpdateSerializerOldRequest() # SubscriptionRecordUpdateSerializerOldRequest |  (optional)
subscription_filters = [lotus_client.SubscriptionFilterRequest()] # list[SubscriptionFilterRequest] | Filter to a specific set of subscription filters. If your billing model only allows for one subscription per customer, you very likely do not need this field. Must be formatted as a JSON-encoded + stringified list of dictionaries, where each dictionary has a key of 'property_name' and a key of 'value'. (optional)

try:
    api_response = api_instance.api_subscriptions_update_create(customer_id, plan_id, body=body, subscription_filters=subscription_filters)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ApiApi->api_subscriptions_update_create: %s\n" % e)

# Configure API key authorization: OrganizationApiKeyAuth
configuration = lotus_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'
# Configure API key authorization: knoxTokenAuth
configuration = lotus_client.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = lotus_client.ApiApi(lotus_client.ApiClient(configuration))
subscription_id = 'subscription_id_example' # str | The ID of the subscription to update.
body = lotus_client.SubscriptionRecordUpdateRequest() # SubscriptionRecordUpdateRequest |  (optional)

try:
    api_response = api_instance.api_subscriptions_update_create2(subscription_id, body=body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ApiApi->api_subscriptions_update_create2: %s\n" % e)

# Configure API key authorization: OrganizationApiKeyAuth
configuration = lotus_client.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'
# Configure API key authorization: knoxTokenAuth
configuration = lotus_client.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = lotus_client.ApiApi(lotus_client.ApiClient(configuration))
body = lotus_client.ConfirmIdemsReceivedRequestRequest() # ConfirmIdemsReceivedRequestRequest | 

try:
    api_response = api_instance.api_verify_idems_received_create(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ApiApi->api_verify_idems_received_create: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to */*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ApiApi* | [**api_credits_create**](docs/ApiApi.md#api_credits_create) | **POST** /api/credits/ | 
*ApiApi* | [**api_credits_list**](docs/ApiApi.md#api_credits_list) | **GET** /api/credits/ | 
*ApiApi* | [**api_credits_retrieve**](docs/ApiApi.md#api_credits_retrieve) | **GET** /api/credits/{credit_id}/ | 
*ApiApi* | [**api_credits_update_create**](docs/ApiApi.md#api_credits_update_create) | **POST** /api/credits/{credit_id}/update/ | 
*ApiApi* | [**api_credits_void_create**](docs/ApiApi.md#api_credits_void_create) | **POST** /api/credits/{credit_id}/void/ | 
*ApiApi* | [**api_customer_feature_access_list**](docs/ApiApi.md#api_customer_feature_access_list) | **GET** /api/customer_feature_access/ | 
*ApiApi* | [**api_customer_metric_access_list**](docs/ApiApi.md#api_customer_metric_access_list) | **GET** /api/customer_metric_access/ | 
*ApiApi* | [**api_customers_cost_analysis_retrieve**](docs/ApiApi.md#api_customers_cost_analysis_retrieve) | **GET** /api/customers/{customer_id}/cost_analysis/ | 
*ApiApi* | [**api_customers_create**](docs/ApiApi.md#api_customers_create) | **POST** /api/customers/ | 
*ApiApi* | [**api_customers_delete_create**](docs/ApiApi.md#api_customers_delete_create) | **POST** /api/customers/{customer_id}/delete/ | 
*ApiApi* | [**api_customers_draft_invoice_retrieve**](docs/ApiApi.md#api_customers_draft_invoice_retrieve) | **GET** /api/customers/{customer_id}/draft_invoice/ | 
*ApiApi* | [**api_customers_list**](docs/ApiApi.md#api_customers_list) | **GET** /api/customers/ | 
*ApiApi* | [**api_customers_retrieve**](docs/ApiApi.md#api_customers_retrieve) | **GET** /api/customers/{customer_id}/ | 
*ApiApi* | [**api_feature_access_retrieve**](docs/ApiApi.md#api_feature_access_retrieve) | **GET** /api/feature_access/ | 
*ApiApi* | [**api_healthcheck_retrieve**](docs/ApiApi.md#api_healthcheck_retrieve) | **GET** /api/healthcheck/ | 
*ApiApi* | [**api_invoices_list**](docs/ApiApi.md#api_invoices_list) | **GET** /api/invoices/ | 
*ApiApi* | [**api_invoices_partial_update**](docs/ApiApi.md#api_invoices_partial_update) | **PATCH** /api/invoices/{invoice_id}/ | 
*ApiApi* | [**api_invoices_pdf_url_retrieve**](docs/ApiApi.md#api_invoices_pdf_url_retrieve) | **GET** /api/invoices/{invoice_id}/pdf_url/ | 
*ApiApi* | [**api_invoices_retrieve**](docs/ApiApi.md#api_invoices_retrieve) | **GET** /api/invoices/{invoice_id}/ | 
*ApiApi* | [**api_metric_access_retrieve**](docs/ApiApi.md#api_metric_access_retrieve) | **GET** /api/metric_access/ | 
*ApiApi* | [**api_ping_retrieve**](docs/ApiApi.md#api_ping_retrieve) | **GET** /api/ping/ | 
*ApiApi* | [**api_plans_create**](docs/ApiApi.md#api_plans_create) | **POST** /api/plans/ | 
*ApiApi* | [**api_plans_get_plan_price_for_customer_create**](docs/ApiApi.md#api_plans_get_plan_price_for_customer_create) | **POST** /api/plans/{plan_id}/get_plan_price_for_customer/ | 
*ApiApi* | [**api_plans_list**](docs/ApiApi.md#api_plans_list) | **GET** /api/plans/ | 
*ApiApi* | [**api_plans_retrieve**](docs/ApiApi.md#api_plans_retrieve) | **GET** /api/plans/{plan_id}/ | 
*ApiApi* | [**api_subscriptions_add_create**](docs/ApiApi.md#api_subscriptions_add_create) | **POST** /api/subscriptions/add/ | 
*ApiApi* | [**api_subscriptions_addons_attach_create**](docs/ApiApi.md#api_subscriptions_addons_attach_create) | **POST** /api/subscriptions/{subscription_id}/addons/attach/ | 
*ApiApi* | [**api_subscriptions_addons_cancel_create**](docs/ApiApi.md#api_subscriptions_addons_cancel_create) | **POST** /api/subscriptions/{subscription_id}/addons/{addon_id}/cancel/ | 
*ApiApi* | [**api_subscriptions_cancel_create**](docs/ApiApi.md#api_subscriptions_cancel_create) | **POST** /api/subscriptions/cancel/ | 
*ApiApi* | [**api_subscriptions_cancel_create2**](docs/ApiApi.md#api_subscriptions_cancel_create2) | **POST** /api/subscriptions/{subscription_id}/cancel/ | 
*ApiApi* | [**api_subscriptions_components_change_prepaid_units_create**](docs/ApiApi.md#api_subscriptions_components_change_prepaid_units_create) | **POST** /api/subscriptions/{subscription_id}/components/{metric_id}/change_prepaid_units/ | 
*ApiApi* | [**api_subscriptions_create**](docs/ApiApi.md#api_subscriptions_create) | **POST** /api/subscriptions/ | 
*ApiApi* | [**api_subscriptions_get_price_for_extension_create**](docs/ApiApi.md#api_subscriptions_get_price_for_extension_create) | **POST** /api/subscriptions/{subscription_id}/get_price_for_extension/ | 
*ApiApi* | [**api_subscriptions_get_price_for_renewal_retrieve**](docs/ApiApi.md#api_subscriptions_get_price_for_renewal_retrieve) | **GET** /api/subscriptions/{subscription_id}/get_price_for_renewal/ | 
*ApiApi* | [**api_subscriptions_list**](docs/ApiApi.md#api_subscriptions_list) | **GET** /api/subscriptions/ | 
*ApiApi* | [**api_subscriptions_retrieve**](docs/ApiApi.md#api_subscriptions_retrieve) | **GET** /api/subscriptions/{subscription_id}/ | 
*ApiApi* | [**api_subscriptions_switch_plan_create**](docs/ApiApi.md#api_subscriptions_switch_plan_create) | **POST** /api/subscriptions/{subscription_id}/switch_plan/ | 
*ApiApi* | [**api_subscriptions_update_create**](docs/ApiApi.md#api_subscriptions_update_create) | **POST** /api/subscriptions/update/ | 
*ApiApi* | [**api_subscriptions_update_create2**](docs/ApiApi.md#api_subscriptions_update_create2) | **POST** /api/subscriptions/{subscription_id}/update/ | 
*ApiApi* | [**api_verify_idems_received_create**](docs/ApiApi.md#api_verify_idems_received_create) | **POST** /api/verify_idems_received/ | 
*AppApi* | [**app_actions_list**](docs/AppApi.md#app_actions_list) | **GET** /app/actions/ | 
*AppApi* | [**app_addon_versions_create**](docs/AppApi.md#app_addon_versions_create) | **POST** /app/addon_versions/ | 
*AppApi* | [**app_addon_versions_delete_create**](docs/AppApi.md#app_addon_versions_delete_create) | **POST** /app/addon_versions/{version_id}/delete/ | 
*AppApi* | [**app_addon_versions_partial_update**](docs/AppApi.md#app_addon_versions_partial_update) | **PATCH** /app/addon_versions/{version_id}/ | 
*AppApi* | [**app_addons_create**](docs/AppApi.md#app_addons_create) | **POST** /app/addons/ | 
*AppApi* | [**app_addons_delete_create**](docs/AppApi.md#app_addons_delete_create) | **POST** /app/addons/{addon_id}/delete/ | 
*AppApi* | [**app_addons_features_add_create**](docs/AppApi.md#app_addons_features_add_create) | **POST** /app/addons/{addon_id}/features/add/ | 
*AppApi* | [**app_addons_list**](docs/AppApi.md#app_addons_list) | **GET** /app/addons/ | 
*AppApi* | [**app_addons_partial_update**](docs/AppApi.md#app_addons_partial_update) | **PATCH** /app/addons/{addon_id}/ | 
*AppApi* | [**app_addons_retrieve**](docs/AppApi.md#app_addons_retrieve) | **GET** /app/addons/{addon_id}/ | 
*AppApi* | [**app_analysis_create**](docs/AppApi.md#app_analysis_create) | **POST** /app/analysis/ | 
*AppApi* | [**app_analysis_list**](docs/AppApi.md#app_analysis_list) | **GET** /app/analysis/ | 
*AppApi* | [**app_analysis_retrieve**](docs/AppApi.md#app_analysis_retrieve) | **GET** /app/analysis/{analysis_id}/ | 
*AppApi* | [**app_api_tokens_create**](docs/AppApi.md#app_api_tokens_create) | **POST** /app/api_tokens/ | 
*AppApi* | [**app_api_tokens_destroy**](docs/AppApi.md#app_api_tokens_destroy) | **DELETE** /app/api_tokens/{prefix}/ | 
*AppApi* | [**app_api_tokens_list**](docs/AppApi.md#app_api_tokens_list) | **GET** /app/api_tokens/ | 
*AppApi* | [**app_api_tokens_roll_create**](docs/AppApi.md#app_api_tokens_roll_create) | **POST** /app/api_tokens/{prefix}/roll/ | 
*AppApi* | [**app_backtests_create**](docs/AppApi.md#app_backtests_create) | **POST** /app/backtests/ | 
*AppApi* | [**app_backtests_list**](docs/AppApi.md#app_backtests_list) | **GET** /app/backtests/ | 
*AppApi* | [**app_backtests_retrieve**](docs/AppApi.md#app_backtests_retrieve) | **GET** /app/backtests/{backtest_id}/ | 
*AppApi* | [**app_credits_create**](docs/AppApi.md#app_credits_create) | **POST** /app/credits/ | 
*AppApi* | [**app_credits_list**](docs/AppApi.md#app_credits_list) | **GET** /app/credits/ | 
*AppApi* | [**app_credits_retrieve**](docs/AppApi.md#app_credits_retrieve) | **GET** /app/credits/{credit_id}/ | 
*AppApi* | [**app_credits_update_create**](docs/AppApi.md#app_credits_update_create) | **POST** /app/credits/{credit_id}/update/ | 
*AppApi* | [**app_credits_void_create**](docs/AppApi.md#app_credits_void_create) | **POST** /app/credits/{credit_id}/void/ | 
*AppApi* | [**app_crm_link_token_create**](docs/AppApi.md#app_crm_link_token_create) | **POST** /app/crm/link_token/ | 
*AppApi* | [**app_crm_list**](docs/AppApi.md#app_crm_list) | **GET** /app/crm/ | 
*AppApi* | [**app_crm_set_customer_source_create**](docs/AppApi.md#app_crm_set_customer_source_create) | **POST** /app/crm/set_customer_source/ | 
*AppApi* | [**app_crm_store_token_create**](docs/AppApi.md#app_crm_store_token_create) | **POST** /app/crm/store_token/ | 
*AppApi* | [**app_customers_cost_analysis_retrieve**](docs/AppApi.md#app_customers_cost_analysis_retrieve) | **GET** /app/customers/{customer_id}/cost_analysis/ | 
*AppApi* | [**app_customers_create**](docs/AppApi.md#app_customers_create) | **POST** /app/customers/ | 
*AppApi* | [**app_customers_delete_create**](docs/AppApi.md#app_customers_delete_create) | **POST** /app/customers/{customer_id}/delete/ | 
*AppApi* | [**app_customers_draft_invoice_retrieve**](docs/AppApi.md#app_customers_draft_invoice_retrieve) | **GET** /app/customers/{customer_id}/draft_invoice/ | 
*AppApi* | [**app_customers_list**](docs/AppApi.md#app_customers_list) | **GET** /app/customers/ | 
*AppApi* | [**app_customers_partial_update**](docs/AppApi.md#app_customers_partial_update) | **PATCH** /app/customers/{customer_id}/ | 
*AppApi* | [**app_customers_retrieve**](docs/AppApi.md#app_customers_retrieve) | **GET** /app/customers/{customer_id}/ | 
*AppApi* | [**app_customers_summary_retrieve**](docs/AppApi.md#app_customers_summary_retrieve) | **GET** /app/customers/summary/ | 
*AppApi* | [**app_customers_totals_retrieve**](docs/AppApi.md#app_customers_totals_retrieve) | **GET** /app/customers/totals/ | 
*AppApi* | [**app_demo_login_create**](docs/AppApi.md#app_demo_login_create) | **POST** /app/demo_login/ | 
*AppApi* | [**app_demo_register_create**](docs/AppApi.md#app_demo_register_create) | **POST** /app/demo_register/ | 
*AppApi* | [**app_events_list**](docs/AppApi.md#app_events_list) | **GET** /app/events/ | 
*AppApi* | [**app_events_properties_retrieve**](docs/AppApi.md#app_events_properties_retrieve) | **GET** /app/events/properties/ | 
*AppApi* | [**app_events_search_list**](docs/AppApi.md#app_events_search_list) | **GET** /app/events/search/ | 
*AppApi* | [**app_external_plan_links_create**](docs/AppApi.md#app_external_plan_links_create) | **POST** /app/external_plan_links/ | 
*AppApi* | [**app_external_plan_links_destroy**](docs/AppApi.md#app_external_plan_links_destroy) | **DELETE** /app/external_plan_links/{external_plan_id}/ | 
*AppApi* | [**app_features_create**](docs/AppApi.md#app_features_create) | **POST** /app/features/ | 
*AppApi* | [**app_features_list**](docs/AppApi.md#app_features_list) | **GET** /app/features/ | 
*AppApi* | [**app_import_customers_create**](docs/AppApi.md#app_import_customers_create) | **POST** /app/import_customers/ | 
*AppApi* | [**app_import_payment_objects_create**](docs/AppApi.md#app_import_payment_objects_create) | **POST** /app/import_payment_objects/ | 
*AppApi* | [**app_import_subscriptions_create**](docs/AppApi.md#app_import_subscriptions_create) | **POST** /app/import_subscriptions/ | 
*AppApi* | [**app_invoices_create**](docs/AppApi.md#app_invoices_create) | **POST** /app/invoices/ | 
*AppApi* | [**app_invoices_list**](docs/AppApi.md#app_invoices_list) | **GET** /app/invoices/ | 
*AppApi* | [**app_invoices_partial_update**](docs/AppApi.md#app_invoices_partial_update) | **PATCH** /app/invoices/{invoice_id}/ | 
*AppApi* | [**app_invoices_pdf_url_retrieve**](docs/AppApi.md#app_invoices_pdf_url_retrieve) | **GET** /app/invoices/{invoice_id}/pdf_url/ | 
*AppApi* | [**app_invoices_retrieve**](docs/AppApi.md#app_invoices_retrieve) | **GET** /app/invoices/{invoice_id}/ | 
*AppApi* | [**app_invoices_send_create**](docs/AppApi.md#app_invoices_send_create) | **POST** /app/invoices/{invoice_id}/send/ | 
*AppApi* | [**app_login_create**](docs/AppApi.md#app_login_create) | **POST** /app/login/ | 
*AppApi* | [**app_logout_create**](docs/AppApi.md#app_logout_create) | **POST** /app/logout/ | 
*AppApi* | [**app_metrics_create**](docs/AppApi.md#app_metrics_create) | **POST** /app/metrics/ | 
*AppApi* | [**app_metrics_list**](docs/AppApi.md#app_metrics_list) | **GET** /app/metrics/ | 
*AppApi* | [**app_metrics_partial_update**](docs/AppApi.md#app_metrics_partial_update) | **PATCH** /app/metrics/{metric_id}/ | 
*AppApi* | [**app_metrics_retrieve**](docs/AppApi.md#app_metrics_retrieve) | **GET** /app/metrics/{metric_id}/ | 
*AppApi* | [**app_netsuite_customers_retrieve**](docs/AppApi.md#app_netsuite_customers_retrieve) | **GET** /app/netsuite_customers/ | 
*AppApi* | [**app_netsuite_invoices_retrieve**](docs/AppApi.md#app_netsuite_invoices_retrieve) | **GET** /app/netsuite_invoices/ | 
*AppApi* | [**app_organization_invite_create**](docs/AppApi.md#app_organization_invite_create) | **POST** /app/organization/invite/ | 
*AppApi* | [**app_organization_invite_link_create**](docs/AppApi.md#app_organization_invite_link_create) | **POST** /app/organization/invite_link/ | 
*AppApi* | [**app_organizations_create**](docs/AppApi.md#app_organizations_create) | **POST** /app/organizations/ | 
*AppApi* | [**app_organizations_list**](docs/AppApi.md#app_organizations_list) | **GET** /app/organizations/ | 
*AppApi* | [**app_organizations_partial_update**](docs/AppApi.md#app_organizations_partial_update) | **PATCH** /app/organizations/{organization_id}/ | 
*AppApi* | [**app_organizations_sync_crm_create**](docs/AppApi.md#app_organizations_sync_crm_create) | **POST** /app/organizations/{organization_id}/sync_crm/ | 
*AppApi* | [**app_payment_providers_create**](docs/AppApi.md#app_payment_providers_create) | **POST** /app/payment_providers/ | 
*AppApi* | [**app_payment_providers_list**](docs/AppApi.md#app_payment_providers_list) | **GET** /app/payment_providers/ | 
*AppApi* | [**app_period_events_retrieve**](docs/AppApi.md#app_period_events_retrieve) | **GET** /app/period_events/ | 
*AppApi* | [**app_period_metric_revenue_retrieve**](docs/AppApi.md#app_period_metric_revenue_retrieve) | **GET** /app/period_metric_revenue/ | 
*AppApi* | [**app_period_metric_usage_retrieve**](docs/AppApi.md#app_period_metric_usage_retrieve) | **GET** /app/period_metric_usage/ | 
*AppApi* | [**app_period_subscriptions_retrieve**](docs/AppApi.md#app_period_subscriptions_retrieve) | **GET** /app/period_subscriptions/ | 
*AppApi* | [**app_plan_versions_create**](docs/AppApi.md#app_plan_versions_create) | **POST** /app/plan_versions/ | 
*AppApi* | [**app_plan_versions_delete_create**](docs/AppApi.md#app_plan_versions_delete_create) | **POST** /app/plan_versions/{version_id}/delete/ | 
*AppApi* | [**app_plan_versions_features_add_create**](docs/AppApi.md#app_plan_versions_features_add_create) | **POST** /app/plan_versions/{version_id}/features/add/ | 
*AppApi* | [**app_plan_versions_list**](docs/AppApi.md#app_plan_versions_list) | **GET** /app/plan_versions/ | 
*AppApi* | [**app_plan_versions_make_public_create**](docs/AppApi.md#app_plan_versions_make_public_create) | **POST** /app/plan_versions/{version_id}/make_public/ | 
*AppApi* | [**app_plan_versions_partial_update**](docs/AppApi.md#app_plan_versions_partial_update) | **PATCH** /app/plan_versions/{version_id}/ | 
*AppApi* | [**app_plan_versions_replacement_make_create**](docs/AppApi.md#app_plan_versions_replacement_make_create) | **POST** /app/plan_versions/{version_id}/replacement/make/ | 
*AppApi* | [**app_plan_versions_replacement_set_create**](docs/AppApi.md#app_plan_versions_replacement_set_create) | **POST** /app/plan_versions/{version_id}/replacement/set/ | 
*AppApi* | [**app_plan_versions_retrieve**](docs/AppApi.md#app_plan_versions_retrieve) | **GET** /app/plan_versions/{version_id}/ | 
*AppApi* | [**app_plan_versions_subscriptions_list**](docs/AppApi.md#app_plan_versions_subscriptions_list) | **GET** /app/plan_versions/{version_id}/subscriptions/ | 
*AppApi* | [**app_plan_versions_target_customers_add_create**](docs/AppApi.md#app_plan_versions_target_customers_add_create) | **POST** /app/plan_versions/{version_id}/target_customers/add/ | 
*AppApi* | [**app_plan_versions_target_customers_remove_create**](docs/AppApi.md#app_plan_versions_target_customers_remove_create) | **POST** /app/plan_versions/{version_id}/target_customers/remove/ | 
*AppApi* | [**app_plans_by_customer_retrieve**](docs/AppApi.md#app_plans_by_customer_retrieve) | **GET** /app/plans_by_customer/ | 
*AppApi* | [**app_plans_create**](docs/AppApi.md#app_plans_create) | **POST** /app/plans/ | 
*AppApi* | [**app_plans_delete_create**](docs/AppApi.md#app_plans_delete_create) | **POST** /app/plans/{plan_id}/delete/ | 
*AppApi* | [**app_plans_features_add_create**](docs/AppApi.md#app_plans_features_add_create) | **POST** /app/plans/{plan_id}/features/add/ | 
*AppApi* | [**app_plans_get_plan_price_for_customer_create**](docs/AppApi.md#app_plans_get_plan_price_for_customer_create) | **POST** /app/plans/{plan_id}/get_plan_price_for_customer/ | 
*AppApi* | [**app_plans_list**](docs/AppApi.md#app_plans_list) | **GET** /app/plans/ | 
*AppApi* | [**app_plans_partial_update**](docs/AppApi.md#app_plans_partial_update) | **PATCH** /app/plans/{plan_id}/ | 
*AppApi* | [**app_plans_retrieve**](docs/AppApi.md#app_plans_retrieve) | **GET** /app/plans/{plan_id}/ | 
*AppApi* | [**app_plans_tags_add_create**](docs/AppApi.md#app_plans_tags_add_create) | **POST** /app/plans/{plan_id}/tags/add/ | 
*AppApi* | [**app_plans_tags_remove_create**](docs/AppApi.md#app_plans_tags_remove_create) | **POST** /app/plans/{plan_id}/tags/remove/ | 
*AppApi* | [**app_plans_tags_set_create**](docs/AppApi.md#app_plans_tags_set_create) | **POST** /app/plans/{plan_id}/tags/set/ | 
*AppApi* | [**app_plans_versions_active_dates_update_create**](docs/AppApi.md#app_plans_versions_active_dates_update_create) | **POST** /app/plans/{plan_id}/versions/{version_number}/active_dates/update/ | 
*AppApi* | [**app_plans_versions_features_add_create**](docs/AppApi.md#app_plans_versions_features_add_create) | **POST** /app/plans/{plan_id}/versions/{version_number}/features/add/ | 
*AppApi* | [**app_plans_versions_next_retrieve**](docs/AppApi.md#app_plans_versions_next_retrieve) | **GET** /app/plans/{plan_id}/versions/next/ | 
*AppApi* | [**app_plans_versions_replacement_set_create**](docs/AppApi.md#app_plans_versions_replacement_set_create) | **POST** /app/plans/{plan_id}/versions/{version_number}/replacement/set/ | 
*AppApi* | [**app_plans_versions_transition_set_create**](docs/AppApi.md#app_plans_versions_transition_set_create) | **POST** /app/plans/{plan_id}/versions/{version_number}/transition/set/ | 
*AppApi* | [**app_pricing_units_create**](docs/AppApi.md#app_pricing_units_create) | **POST** /app/pricing_units/ | 
*AppApi* | [**app_pricing_units_list**](docs/AppApi.md#app_pricing_units_list) | **GET** /app/pricing_units/ | 
*AppApi* | [**app_register_create**](docs/AppApi.md#app_register_create) | **POST** /app/register/ | 
*AppApi* | [**app_session_retrieve**](docs/AppApi.md#app_session_retrieve) | **GET** /app/session/ | 
*AppApi* | [**app_stripe_cancel_at_period_end_subscriptions_create**](docs/AppApi.md#app_stripe_cancel_at_period_end_subscriptions_create) | **POST** /app/stripe/cancel_at_period_end_subscriptions/ | 
*AppApi* | [**app_stripe_cancel_subscriptions_create**](docs/AppApi.md#app_stripe_cancel_subscriptions_create) | **POST** /app/stripe/cancel_subscriptions/ | 
*AppApi* | [**app_subscriptions_add_create**](docs/AppApi.md#app_subscriptions_add_create) | **POST** /app/subscriptions/add/ | 
*AppApi* | [**app_subscriptions_addons_attach_create**](docs/AppApi.md#app_subscriptions_addons_attach_create) | **POST** /app/subscriptions/{subscription_id}/addons/attach/ | 
*AppApi* | [**app_subscriptions_addons_cancel_create**](docs/AppApi.md#app_subscriptions_addons_cancel_create) | **POST** /app/subscriptions/{subscription_id}/addons/{addon_id}/cancel/ | 
*AppApi* | [**app_subscriptions_cancel_create**](docs/AppApi.md#app_subscriptions_cancel_create) | **POST** /app/subscriptions/cancel/ | 
*AppApi* | [**app_subscriptions_cancel_create2**](docs/AppApi.md#app_subscriptions_cancel_create2) | **POST** /app/subscriptions/{subscription_id}/cancel/ | 
*AppApi* | [**app_subscriptions_components_change_prepaid_units_create**](docs/AppApi.md#app_subscriptions_components_change_prepaid_units_create) | **POST** /app/subscriptions/{subscription_id}/components/{metric_id}/change_prepaid_units/ | 
*AppApi* | [**app_subscriptions_create**](docs/AppApi.md#app_subscriptions_create) | **POST** /app/subscriptions/ | 
*AppApi* | [**app_subscriptions_get_price_for_extension_create**](docs/AppApi.md#app_subscriptions_get_price_for_extension_create) | **POST** /app/subscriptions/{subscription_id}/get_price_for_extension/ | 
*AppApi* | [**app_subscriptions_get_price_for_renewal_retrieve**](docs/AppApi.md#app_subscriptions_get_price_for_renewal_retrieve) | **GET** /app/subscriptions/{subscription_id}/get_price_for_renewal/ | 
*AppApi* | [**app_subscriptions_list**](docs/AppApi.md#app_subscriptions_list) | **GET** /app/subscriptions/ | 
*AppApi* | [**app_subscriptions_retrieve**](docs/AppApi.md#app_subscriptions_retrieve) | **GET** /app/subscriptions/{subscription_id}/ | 
*AppApi* | [**app_subscriptions_switch_plan_create**](docs/AppApi.md#app_subscriptions_switch_plan_create) | **POST** /app/subscriptions/{subscription_id}/switch_plan/ | 
*AppApi* | [**app_subscriptions_update_create**](docs/AppApi.md#app_subscriptions_update_create) | **POST** /app/subscriptions/update/ | 
*AppApi* | [**app_subscriptions_update_create2**](docs/AppApi.md#app_subscriptions_update_create2) | **POST** /app/subscriptions/{subscription_id}/update/ | 
*AppApi* | [**app_switch_organization_create**](docs/AppApi.md#app_switch_organization_create) | **POST** /app/switch_organization/ | 
*AppApi* | [**app_timezones_retrieve**](docs/AppApi.md#app_timezones_retrieve) | **GET** /app/timezones/ | 
*AppApi* | [**app_transfer_subscriptions_create**](docs/AppApi.md#app_transfer_subscriptions_create) | **POST** /app/transfer_subscriptions/ | 
*AppApi* | [**app_usage_alerts_create**](docs/AppApi.md#app_usage_alerts_create) | **POST** /app/usage_alerts/ | 
*AppApi* | [**app_usage_alerts_destroy**](docs/AppApi.md#app_usage_alerts_destroy) | **DELETE** /app/usage_alerts/{usage_alert_id}/ | 
*AppApi* | [**app_usage_alerts_list**](docs/AppApi.md#app_usage_alerts_list) | **GET** /app/usage_alerts/ | 
*AppApi* | [**app_usage_alerts_retrieve**](docs/AppApi.md#app_usage_alerts_retrieve) | **GET** /app/usage_alerts/{usage_alert_id}/ | 
*AppApi* | [**app_user_password_reset_create**](docs/AppApi.md#app_user_password_reset_create) | **POST** /app/user/password/reset/ | 
*AppApi* | [**app_user_password_reset_init_create**](docs/AppApi.md#app_user_password_reset_init_create) | **POST** /app/user/password/reset/init/ | 
*AppApi* | [**app_users_create**](docs/AppApi.md#app_users_create) | **POST** /app/users/ | 
*AppApi* | [**app_users_list**](docs/AppApi.md#app_users_list) | **GET** /app/users/ | 
*AppApi* | [**app_webhooks_create**](docs/AppApi.md#app_webhooks_create) | **POST** /app/webhooks/ | 
*AppApi* | [**app_webhooks_destroy**](docs/AppApi.md#app_webhooks_destroy) | **DELETE** /app/webhooks/{webhook_endpoint_id}/ | 
*AppApi* | [**app_webhooks_list**](docs/AppApi.md#app_webhooks_list) | **GET** /app/webhooks/ | 
*AppApi* | [**app_webhooks_retrieve**](docs/AppApi.md#app_webhooks_retrieve) | **GET** /app/webhooks/{webhook_endpoint_id}/ | 
*StripeApi* | [**stripe_webhook_create**](docs/StripeApi.md#stripe_webhook_create) | **POST** /stripe/webhook/ | 

## Documentation For Models

 - [APIToken](docs/APIToken.md)
 - [APITokenCreateResponse](docs/APITokenCreateResponse.md)
 - [APITokenRequest](docs/APITokenRequest.md)
 - [APITokenRollResponse](docs/APITokenRollResponse.md)
 - [AccessMethodsSubscriptionRecord](docs/AccessMethodsSubscriptionRecord.md)
 - [Action](docs/Action.md)
 - [AddFeatureRequest](docs/AddFeatureRequest.md)
 - [AddFeatureResponse](docs/AddFeatureResponse.md)
 - [AddFeatureToAddOnRequest](docs/AddFeatureToAddOnRequest.md)
 - [AddFeatureToAddOnResponse](docs/AddFeatureToAddOnResponse.md)
 - [AddFeatureToPlanRequest](docs/AddFeatureToPlanRequest.md)
 - [AddFeatureToPlanResponse](docs/AddFeatureToPlanResponse.md)
 - [AddFeatureToPlanVersionNumberResponse](docs/AddFeatureToPlanVersionNumberResponse.md)
 - [AddOnCreateRequest](docs/AddOnCreateRequest.md)
 - [AddOnDetail](docs/AddOnDetail.md)
 - [AddOnSubscriptionRecord](docs/AddOnSubscriptionRecord.md)
 - [AddOnSubscriptionRecordCreateRequest](docs/AddOnSubscriptionRecordCreateRequest.md)
 - [AddOnUpdate](docs/AddOnUpdate.md)
 - [AddOnVersion](docs/AddOnVersion.md)
 - [AddOnVersionCreateRequest](docs/AddOnVersionCreateRequest.md)
 - [AddOnVersionDetail](docs/AddOnVersionDetail.md)
 - [AddOnVersionUpdate](docs/AddOnVersionUpdate.md)
 - [AddPlanTags](docs/AddPlanTags.md)
 - [AddPlanTagsRequest](docs/AddPlanTagsRequest.md)
 - [AddTargetCustomerResponse](docs/AddTargetCustomerResponse.md)
 - [Address](docs/Address.md)
 - [AddressRequest](docs/AddressRequest.md)
 - [AllOfAddOnCreateRequestInitialVersion](docs/AllOfAddOnCreateRequestInitialVersion.md)
 - [AllOfAddOnVersionCurrency](docs/AllOfAddOnVersionCurrency.md)
 - [AllOfAddOnVersionDetailCurrency](docs/AllOfAddOnVersionDetailCurrency.md)
 - [AllOfAnalysisDetailAnalysisResults](docs/AllOfAnalysisDetailAnalysisResults.md)
 - [AllOfCustomerAddress](docs/AllOfCustomerAddress.md)
 - [AllOfCustomerBalanceAdjustmentAmountPaidCurrency](docs/AllOfCustomerBalanceAdjustmentAmountPaidCurrency.md)
 - [AllOfCustomerBillingAddress](docs/AllOfCustomerBillingAddress.md)
 - [AllOfCustomerCreateRequestAddress](docs/AllOfCustomerCreateRequestAddress.md)
 - [AllOfCustomerCreateRequestBillingAddress](docs/AllOfCustomerCreateRequestBillingAddress.md)
 - [AllOfCustomerCreateRequestShippingAddress](docs/AllOfCustomerCreateRequestShippingAddress.md)
 - [AllOfCustomerDetailAddress](docs/AllOfCustomerDetailAddress.md)
 - [AllOfCustomerDetailBillingAddress](docs/AllOfCustomerDetailBillingAddress.md)
 - [AllOfCustomerDetailIntegrations](docs/AllOfCustomerDetailIntegrations.md)
 - [AllOfCustomerDetailShippingAddress](docs/AllOfCustomerDetailShippingAddress.md)
 - [AllOfCustomerIntegrations](docs/AllOfCustomerIntegrations.md)
 - [AllOfCustomerIntegrationsBraintree](docs/AllOfCustomerIntegrationsBraintree.md)
 - [AllOfCustomerIntegrationsStripe](docs/AllOfCustomerIntegrationsStripe.md)
 - [AllOfCustomerShippingAddress](docs/AllOfCustomerShippingAddress.md)
 - [AllOfCustomerUpdateBillingAddress](docs/AllOfCustomerUpdateBillingAddress.md)
 - [AllOfCustomerUpdateShippingAddress](docs/AllOfCustomerUpdateShippingAddress.md)
 - [AllOfInvoiceLineItemPlan](docs/AllOfInvoiceLineItemPlan.md)
 - [AllOfLightweightCustomerSerializerForInvoiceAddress](docs/AllOfLightweightCustomerSerializerForInvoiceAddress.md)
 - [AllOfLightweightSubscriptionRecordPlanDetail](docs/AllOfLightweightSubscriptionRecordPlanDetail.md)
 - [AllOfOrganizationAddress](docs/AllOfOrganizationAddress.md)
 - [AllOfOrganizationCurrentUser](docs/AllOfOrganizationCurrentUser.md)
 - [AllOfPatchedCustomerUpdateRequestBillingAddress](docs/AllOfPatchedCustomerUpdateRequestBillingAddress.md)
 - [AllOfPatchedCustomerUpdateRequestShippingAddress](docs/AllOfPatchedCustomerUpdateRequestShippingAddress.md)
 - [AllOfPatchedOrganizationUpdateRequestAddress](docs/AllOfPatchedOrganizationUpdateRequestAddress.md)
 - [AllOfPlanComponentCreateRequestPrepaidCharge](docs/AllOfPlanComponentCreateRequestPrepaidCharge.md)
 - [AllOfPlanComponentPrepaidCharge](docs/AllOfPlanComponentPrepaidCharge.md)
 - [AllOfPlanComponentRequestPrepaidCharge](docs/AllOfPlanComponentRequestPrepaidCharge.md)
 - [AllOfPlanDisplayVersion](docs/AllOfPlanDisplayVersion.md)
 - [AllOfPlanParentPlan](docs/AllOfPlanParentPlan.md)
 - [AllOfPlanTargetCustomer](docs/AllOfPlanTargetCustomer.md)
 - [AllOfPlanVersionDetailPriceAdjustment](docs/AllOfPlanVersionDetailPriceAdjustment.md)
 - [AllOfPlanVersionPriceAdjustment](docs/AllOfPlanVersionPriceAdjustment.md)
 - [AllOfPlanVersionRequestPriceAdjustment](docs/AllOfPlanVersionRequestPriceAdjustment.md)
 - [AllOfSellerAddress](docs/AllOfSellerAddress.md)
 - [AllSubstitutionResults](docs/AllSubstitutionResults.md)
 - [AnalysisDetail](docs/AnalysisDetail.md)
 - [AnalysisResults](docs/AnalysisResults.md)
 - [AnalysisSummary](docs/AnalysisSummary.md)
 - [BacktestCreate](docs/BacktestCreate.md)
 - [BacktestCreateRequest](docs/BacktestCreateRequest.md)
 - [BacktestDetail](docs/BacktestDetail.md)
 - [BacktestSubstitution](docs/BacktestSubstitution.md)
 - [BacktestSubstitutionMulti](docs/BacktestSubstitutionMulti.md)
 - [BacktestSubstitutionMultiRequest](docs/BacktestSubstitutionMultiRequest.md)
 - [BacktestSummary](docs/BacktestSummary.md)
 - [CRMSyncRequestRequest](docs/CRMSyncRequestRequest.md)
 - [CategoricalFilter](docs/CategoricalFilter.md)
 - [CategoricalFilterDetailRequest](docs/CategoricalFilterDetailRequest.md)
 - [CategoricalFilterRequest](docs/CategoricalFilterRequest.md)
 - [ChangeActiveDateResponse](docs/ChangeActiveDateResponse.md)
 - [ChangeActiveDatesRequest](docs/ChangeActiveDatesRequest.md)
 - [ChangePrepaidUnitsRequest](docs/ChangePrepaidUnitsRequest.md)
 - [ChangeUserOrganizationRequestRequest](docs/ChangeUserOrganizationRequestRequest.md)
 - [ComponentCharge](docs/ComponentCharge.md)
 - [ComponentChargeCreateRequest](docs/ComponentChargeCreateRequest.md)
 - [ComponentChargeRequest](docs/ComponentChargeRequest.md)
 - [ComponentUsage](docs/ComponentUsage.md)
 - [ComponentsFixedChargeInitialValueRequest](docs/ComponentsFixedChargeInitialValueRequest.md)
 - [ConfirmConnected](docs/ConfirmConnected.md)
 - [ConfirmIdemsReceived](docs/ConfirmIdemsReceived.md)
 - [ConfirmIdemsReceivedFailure](docs/ConfirmIdemsReceivedFailure.md)
 - [ConfirmIdemsReceivedRequestRequest](docs/ConfirmIdemsReceivedRequestRequest.md)
 - [CostAnalysis](docs/CostAnalysis.md)
 - [CreditDrawdown](docs/CreditDrawdown.md)
 - [Customer](docs/Customer.md)
 - [CustomerBalanceAdjustment](docs/CustomerBalanceAdjustment.md)
 - [CustomerBalanceAdjustmentCreateRequest](docs/CustomerBalanceAdjustmentCreateRequest.md)
 - [CustomerBalanceAdjustmentUpdateRequest](docs/CustomerBalanceAdjustmentUpdateRequest.md)
 - [CustomerBraintreeIntegration](docs/CustomerBraintreeIntegration.md)
 - [CustomerCreateRequest](docs/CustomerCreateRequest.md)
 - [CustomerCreatedRequest](docs/CustomerCreatedRequest.md)
 - [CustomerDeleteResponse](docs/CustomerDeleteResponse.md)
 - [CustomerDetail](docs/CustomerDetail.md)
 - [CustomerIntegrations](docs/CustomerIntegrations.md)
 - [CustomerPlanPriceRequest](docs/CustomerPlanPriceRequest.md)
 - [CustomerRequest](docs/CustomerRequest.md)
 - [CustomerStripeIntegration](docs/CustomerStripeIntegration.md)
 - [CustomerSummary](docs/CustomerSummary.md)
 - [CustomerUpdate](docs/CustomerUpdate.md)
 - [CustomerWithRevenue](docs/CustomerWithRevenue.md)
 - [DayMetricUsage](docs/DayMetricUsage.md)
 - [DeleteAddOn](docs/DeleteAddOn.md)
 - [DeleteAddOnVersion](docs/DeleteAddOnVersion.md)
 - [DeletePlan](docs/DeletePlan.md)
 - [DeletePlanVersion](docs/DeletePlanVersion.md)
 - [DemoLoginFailure](docs/DemoLoginFailure.md)
 - [DemoLoginRequestRequest](docs/DemoLoginRequestRequest.md)
 - [DemoLoginSuccess](docs/DemoLoginSuccess.md)
 - [DemoRegistrationDetailRequest](docs/DemoRegistrationDetailRequest.md)
 - [DemoRegistrationFailure](docs/DemoRegistrationFailure.md)
 - [DemoRegistrationRequest](docs/DemoRegistrationRequest.md)
 - [DemoRegistrationSuccess](docs/DemoRegistrationSuccess.md)
 - [EmailRequest](docs/EmailRequest.md)
 - [EventDetail](docs/EventDetail.md)
 - [EventProperties](docs/EventProperties.md)
 - [ExternalPlanLink](docs/ExternalPlanLink.md)
 - [ExternalPlanLinkRequest](docs/ExternalPlanLinkRequest.md)
 - [Feature](docs/Feature.md)
 - [FeatureAccessPerSubscription](docs/FeatureAccessPerSubscription.md)
 - [FeatureAccessResponse](docs/FeatureAccessResponse.md)
 - [FeatureCreateRequest](docs/FeatureCreateRequest.md)
 - [FeatureDetail](docs/FeatureDetail.md)
 - [FeatureRequest](docs/FeatureRequest.md)
 - [GetEventAccess](docs/GetEventAccess.md)
 - [GetFeatureAccess](docs/GetFeatureAccess.md)
 - [ImportCustomerFailure](docs/ImportCustomerFailure.md)
 - [ImportCustomerSuccess](docs/ImportCustomerSuccess.md)
 - [ImportCustomersRequestRequest](docs/ImportCustomersRequestRequest.md)
 - [ImportPaymentObjectFailure](docs/ImportPaymentObjectFailure.md)
 - [ImportPaymentObjectSuccess](docs/ImportPaymentObjectSuccess.md)
 - [ImportPaymentObjectsRequestRequest](docs/ImportPaymentObjectsRequestRequest.md)
 - [ImportSubscriptionsFailure](docs/ImportSubscriptionsFailure.md)
 - [ImportSubscriptionsRequestRequest](docs/ImportSubscriptionsRequestRequest.md)
 - [ImportSubscriptionsSuccess](docs/ImportSubscriptionsSuccess.md)
 - [InitResetPasswordSuccess](docs/InitResetPasswordSuccess.md)
 - [InitialAddOnVersionCreateRequest](docs/InitialAddOnVersionCreateRequest.md)
 - [InitialExternalPlanLink](docs/InitialExternalPlanLink.md)
 - [InitialExternalPlanLinkRequest](docs/InitialExternalPlanLinkRequest.md)
 - [InitialPlanVersionCreateRequest](docs/InitialPlanVersionCreateRequest.md)
 - [InviteLinkResponse](docs/InviteLinkResponse.md)
 - [InviteRequestRequest](docs/InviteRequestRequest.md)
 - [InviteResponse](docs/InviteResponse.md)
 - [Invoice](docs/Invoice.md)
 - [InvoiceCreatedRequest](docs/InvoiceCreatedRequest.md)
 - [InvoiceDetail](docs/InvoiceDetail.md)
 - [InvoiceDetailRequest](docs/InvoiceDetailRequest.md)
 - [InvoiceLineItem](docs/InvoiceLineItem.md)
 - [InvoiceLineItemAdjustment](docs/InvoiceLineItemAdjustment.md)
 - [InvoiceLineItemRequest](docs/InvoiceLineItemRequest.md)
 - [InvoicePaidRequest](docs/InvoicePaidRequest.md)
 - [InvoicePastDueRequest](docs/InvoicePastDueRequest.md)
 - [InvoicePayment](docs/InvoicePayment.md)
 - [InvoiceRequest](docs/InvoiceRequest.md)
 - [LightweightAddOn](docs/LightweightAddOn.md)
 - [LightweightAddOnRequest](docs/LightweightAddOnRequest.md)
 - [LightweightAddOnSubscriptionRecord](docs/LightweightAddOnSubscriptionRecord.md)
 - [LightweightAddOnSubscriptionRecordRequest](docs/LightweightAddOnSubscriptionRecordRequest.md)
 - [LightweightCustomer](docs/LightweightCustomer.md)
 - [LightweightCustomerSerializerForInvoice](docs/LightweightCustomerSerializerForInvoice.md)
 - [LightweightInvoice](docs/LightweightInvoice.md)
 - [LightweightInvoiceDetail](docs/LightweightInvoiceDetail.md)
 - [LightweightMetric](docs/LightweightMetric.md)
 - [LightweightOrganization](docs/LightweightOrganization.md)
 - [LightweightPlan](docs/LightweightPlan.md)
 - [LightweightPlanVersion](docs/LightweightPlanVersion.md)
 - [LightweightPlanVersionRequest](docs/LightweightPlanVersionRequest.md)
 - [LightweightSubscriptionRecord](docs/LightweightSubscriptionRecord.md)
 - [LightweightSubscriptionRecordRequest](docs/LightweightSubscriptionRecordRequest.md)
 - [LightweightUser](docs/LightweightUser.md)
 - [LinkTokenResponse](docs/LinkTokenResponse.md)
 - [LoginFailure](docs/LoginFailure.md)
 - [LoginRequestRequest](docs/LoginRequestRequest.md)
 - [LoginSuccess](docs/LoginSuccess.md)
 - [LogoutFailure](docs/LogoutFailure.md)
 - [LogoutSuccess](docs/LogoutSuccess.md)
 - [MakePublicRequestRequest](docs/MakePublicRequestRequest.md)
 - [MakePublicResponse](docs/MakePublicResponse.md)
 - [MakeReplaceWithRequest](docs/MakeReplaceWithRequest.md)
 - [MakeReplaceWithResponse](docs/MakeReplaceWithResponse.md)
 - [Metric](docs/Metric.md)
 - [MetricAccessPerSubscription](docs/MetricAccessPerSubscription.md)
 - [MetricAccessResponse](docs/MetricAccessResponse.md)
 - [MetricCreateRequest](docs/MetricCreateRequest.md)
 - [MetricDetail](docs/MetricDetail.md)
 - [MetricRequest](docs/MetricRequest.md)
 - [MetricRevenue](docs/MetricRevenue.md)
 - [MetricUpdate](docs/MetricUpdate.md)
 - [NextPlanVersionNumberResponse](docs/NextPlanVersionNumberResponse.md)
 - [NumericFilter](docs/NumericFilter.md)
 - [NumericFilterDetailRequest](docs/NumericFilterDetailRequest.md)
 - [NumericFilterRequest](docs/NumericFilterRequest.md)
 - [OneOfLightweightPlanVersionVersion](docs/OneOfLightweightPlanVersionVersion.md)
 - [OneOfPlanVersionDetailVersion](docs/OneOfPlanVersionDetailVersion.md)
 - [OneOfPlanVersionVersion](docs/OneOfPlanVersionVersion.md)
 - [Organization](docs/Organization.md)
 - [OrganizationCreateRequest](docs/OrganizationCreateRequest.md)
 - [OrganizationUser](docs/OrganizationUser.md)
 - [PaginatedActionList](docs/PaginatedActionList.md)
 - [PaginatedEventDetailList](docs/PaginatedEventDetailList.md)
 - [PatchedAddOnUpdateRequest](docs/PatchedAddOnUpdateRequest.md)
 - [PatchedAddOnVersionUpdateRequest](docs/PatchedAddOnVersionUpdateRequest.md)
 - [PatchedCustomerUpdateRequest](docs/PatchedCustomerUpdateRequest.md)
 - [PatchedInvoiceUpdateRequest](docs/PatchedInvoiceUpdateRequest.md)
 - [PatchedMetricUpdateRequest](docs/PatchedMetricUpdateRequest.md)
 - [PatchedOrganizationUpdateRequest](docs/PatchedOrganizationUpdateRequest.md)
 - [PatchedPlanUpdateRequest](docs/PatchedPlanUpdateRequest.md)
 - [PatchedPlanVersionUpdateRequest](docs/PatchedPlanVersionUpdateRequest.md)
 - [PaymentProcesorPostDataRequest](docs/PaymentProcesorPostDataRequest.md)
 - [PaymentProcesorPostRequestRequest](docs/PaymentProcesorPostRequestRequest.md)
 - [PaymentProcesorPostResponse](docs/PaymentProcesorPostResponse.md)
 - [PerPlanPerDay](docs/PerPlanPerDay.md)
 - [PeriodMetricRevenueResponse](docs/PeriodMetricRevenueResponse.md)
 - [PeriodMetricUsageResponse](docs/PeriodMetricUsageResponse.md)
 - [PeriodSingleMetricUsage](docs/PeriodSingleMetricUsage.md)
 - [PeriodSubscriptionsResponse](docs/PeriodSubscriptionsResponse.md)
 - [Plan](docs/Plan.md)
 - [PlanComponent](docs/PlanComponent.md)
 - [PlanComponentCreateRequest](docs/PlanComponentCreateRequest.md)
 - [PlanComponentRequest](docs/PlanComponentRequest.md)
 - [PlanCreateRequest](docs/PlanCreateRequest.md)
 - [PlanDetail](docs/PlanDetail.md)
 - [PlanNameAndID](docs/PlanNameAndID.md)
 - [PlanRepresentation](docs/PlanRepresentation.md)
 - [PlanRequest](docs/PlanRequest.md)
 - [PlanUpdate](docs/PlanUpdate.md)
 - [PlanVersion](docs/PlanVersion.md)
 - [PlanVersionCreateRequest](docs/PlanVersionCreateRequest.md)
 - [PlanVersionDetail](docs/PlanVersionDetail.md)
 - [PlanVersionHistoricalSubscription](docs/PlanVersionHistoricalSubscription.md)
 - [PlanVersionNumberSetReplaceWithResponse](docs/PlanVersionNumberSetReplaceWithResponse.md)
 - [PlanVersionNumberSetTransitionToResponse](docs/PlanVersionNumberSetTransitionToResponse.md)
 - [PlanVersionRequest](docs/PlanVersionRequest.md)
 - [PlanVersionUpdate](docs/PlanVersionUpdate.md)
 - [PlansByNumCustomers](docs/PlansByNumCustomers.md)
 - [PlansSetReplaceWithForVersionNumberRequest](docs/PlansSetReplaceWithForVersionNumberRequest.md)
 - [PlansSetTransitionToForVersionNumberRequest](docs/PlansSetTransitionToForVersionNumberRequest.md)
 - [Price](docs/Price.md)
 - [PriceAdjustment](docs/PriceAdjustment.md)
 - [PriceAdjustmentRequest](docs/PriceAdjustmentRequest.md)
 - [PriceTier](docs/PriceTier.md)
 - [PriceTierCreateRequest](docs/PriceTierCreateRequest.md)
 - [PriceTierRequest](docs/PriceTierRequest.md)
 - [PricingUnit](docs/PricingUnit.md)
 - [PricingUnitDetail](docs/PricingUnitDetail.md)
 - [PricingUnitDetailRequest](docs/PricingUnitDetailRequest.md)
 - [PricingUnitRequest](docs/PricingUnitRequest.md)
 - [RecurringCharge](docs/RecurringCharge.md)
 - [RecurringChargeCreateRequest](docs/RecurringChargeCreateRequest.md)
 - [RegistrationDetailRequest](docs/RegistrationDetailRequest.md)
 - [RegistrationFailure](docs/RegistrationFailure.md)
 - [RegistrationRequest](docs/RegistrationRequest.md)
 - [RegistrationSuccess](docs/RegistrationSuccess.md)
 - [RemovePlanTags](docs/RemovePlanTags.md)
 - [RemovePlanTagsRequest](docs/RemovePlanTagsRequest.md)
 - [RemoveTargetCustomerResponse](docs/RemoveTargetCustomerResponse.md)
 - [ResetPasswordRequestRequest](docs/ResetPasswordRequestRequest.md)
 - [ResetPasswordSuccess](docs/ResetPasswordSuccess.md)
 - [RevenueByMetric](docs/RevenueByMetric.md)
 - [RevenueByPlanMetric](docs/RevenueByPlanMetric.md)
 - [RevenueDate](docs/RevenueDate.md)
 - [RevenuePerDay](docs/RevenuePerDay.md)
 - [Seller](docs/Seller.md)
 - [SellerRequest](docs/SellerRequest.md)
 - [SessionSuccess](docs/SessionSuccess.md)
 - [SetPlanTagsRequest](docs/SetPlanTagsRequest.md)
 - [SetPlanTagsResponse](docs/SetPlanTagsResponse.md)
 - [SetReplaceWithRequest](docs/SetReplaceWithRequest.md)
 - [SetReplaceWithResponse](docs/SetReplaceWithResponse.md)
 - [SingleCRMProvider](docs/SingleCRMProvider.md)
 - [SingleCustomerValue](docs/SingleCustomerValue.md)
 - [SingleDayCostAnalysis](docs/SingleDayCostAnalysis.md)
 - [SingleKPI](docs/SingleKPI.md)
 - [SingleMetricCost](docs/SingleMetricCost.md)
 - [SinglePaymentProcesor](docs/SinglePaymentProcesor.md)
 - [SinglePlanAnalysis](docs/SinglePlanAnalysis.md)
 - [SinglePlanNumCustomers](docs/SinglePlanNumCustomers.md)
 - [SingleSubstitution](docs/SingleSubstitution.md)
 - [SingleSubstitutionResults](docs/SingleSubstitutionResults.md)
 - [StoreTokenRequestRequest](docs/StoreTokenRequestRequest.md)
 - [StoreTokenResponse](docs/StoreTokenResponse.md)
 - [StripeCancelSubscriptionsFailure](docs/StripeCancelSubscriptionsFailure.md)
 - [StripeCancelSubscriptionsSuccess](docs/StripeCancelSubscriptionsSuccess.md)
 - [StripeMultiSubscriptionsRequest](docs/StripeMultiSubscriptionsRequest.md)
 - [StripeSubscriptionRecord](docs/StripeSubscriptionRecord.md)
 - [StripeTurnOffAutoRenewalFailure](docs/StripeTurnOffAutoRenewalFailure.md)
 - [StripeTurnOffAutoRenewalSuccess](docs/StripeTurnOffAutoRenewalSuccess.md)
 - [SubscriptionCancelledRequest](docs/SubscriptionCancelledRequest.md)
 - [SubscriptionCreatedRequest](docs/SubscriptionCreatedRequest.md)
 - [SubscriptionCustomerSummary](docs/SubscriptionCustomerSummary.md)
 - [SubscriptionFilter](docs/SubscriptionFilter.md)
 - [SubscriptionFilterRequest](docs/SubscriptionFilterRequest.md)
 - [SubscriptionRecord](docs/SubscriptionRecord.md)
 - [SubscriptionRecordCancelRequest](docs/SubscriptionRecordCancelRequest.md)
 - [SubscriptionRecordCreateRequest](docs/SubscriptionRecordCreateRequest.md)
 - [SubscriptionRecordCreateSerializerOldRequest](docs/SubscriptionRecordCreateSerializerOldRequest.md)
 - [SubscriptionRecordRequest](docs/SubscriptionRecordRequest.md)
 - [SubscriptionRecordSwitchPlanRequest](docs/SubscriptionRecordSwitchPlanRequest.md)
 - [SubscriptionRecordUpdateRequest](docs/SubscriptionRecordUpdateRequest.md)
 - [SubscriptionRecordUpdateSerializerOldRequest](docs/SubscriptionRecordUpdateSerializerOldRequest.md)
 - [SubscriptionRenewedRequest](docs/SubscriptionRenewedRequest.md)
 - [SuccessResponse](docs/SuccessResponse.md)
 - [Tag](docs/Tag.md)
 - [TagRequest](docs/TagRequest.md)
 - [TargetCustomersRequest](docs/TargetCustomersRequest.md)
 - [TimezonesResponse](docs/TimezonesResponse.md)
 - [TopCustomers](docs/TopCustomers.md)
 - [TopCustomersPerPlanAnalysis](docs/TopCustomersPerPlanAnalysis.md)
 - [TransferSubscriptionsFailure](docs/TransferSubscriptionsFailure.md)
 - [TransferSubscriptionsRequestRequest](docs/TransferSubscriptionsRequestRequest.md)
 - [TransferSubscriptionsSuccess](docs/TransferSubscriptionsSuccess.md)
 - [URLResponse](docs/URLResponse.md)
 - [UnitMetricExtensionRequest](docs/UnitMetricExtensionRequest.md)
 - [UpdateCRMSourceOfTruthRequest](docs/UpdateCRMSourceOfTruthRequest.md)
 - [UsageAlert](docs/UsageAlert.md)
 - [UsageAlertCreate](docs/UsageAlertCreate.md)
 - [UsageAlertCreateRequest](docs/UsageAlertCreateRequest.md)
 - [UsageAlertPayloadRequest](docs/UsageAlertPayloadRequest.md)
 - [UsageAlertRequest](docs/UsageAlertRequest.md)
 - [UsageAlertTriggeredRequest](docs/UsageAlertTriggeredRequest.md)
 - [User](docs/User.md)
 - [UserRequest](docs/UserRequest.md)
 - [WebhookEndpoint](docs/WebhookEndpoint.md)
 - [WebhookEndpointRequest](docs/WebhookEndpointRequest.md)
 - [WebhookTrigger](docs/WebhookTrigger.md)
 - [WebhookTriggerRequest](docs/WebhookTriggerRequest.md)

## Documentation For Authorization


## OrganizationApiKeyAuth

- **Type**: API key
- **API key parameter name**: X-API-KEY
- **Location**: HTTP header

## basicAuth

- **Type**: HTTP basic authentication

## knoxTokenAuth

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header


## Author


